@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use App::bif::Context;
 
-our $VERSION = '0.1.0_6';
+our $VERSION = '0.1.0_7';
 
 sub run {
     my $ctx = App::bif::Context->new(shift);
@@ -20,7 +20,7 @@ sub run {
     else {
         if ( $info->{kind} eq 'issue' ) {
 
-            my $pinfo = $db->get_project( $ctx->{path} )
+            my $pinfo = $ctx->get_project( $ctx->{path} )
               || return $ctx->err( 'ProjectNotFound',
                 'project not found: ' . $ctx->{path} );
 
@@ -129,7 +129,7 @@ bif-push - push a thread to another project
 
 =head1 VERSION
 
-0.1.0_6 (2014-04-11)
+0.1.0_7 (2014-04-15)
 
 =head1 SYNOPSIS
 
